@@ -166,7 +166,7 @@
     <message>
         <location filename="../gtkconfig.ui" line="44"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Estil GTK</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="63"/>
@@ -225,8 +225,18 @@ Assegureu-vos que «xsettingsd» està instal·lat perquè ajudi a les aplicacio
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Anul·la el fons de pantalla definit per l&apos;usuari</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Utilitza el fons de pantalla predeterminat del tema</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Tema de l&apos;usuari)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Obre la carpeta de temes</translation>
     </message>
 </context>
 <context>
@@ -283,7 +293,7 @@ Assegureu-vos que «xsettingsd» està instal·lat perquè ajudi a les aplicacio
     <message>
         <location filename="../main.cpp" line="118"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Estil GTK</translation>
     </message>
 </context>
 <context>
