@@ -225,8 +225,18 @@ Aby bylo možné u GTK aplikací změnit motiv vzhledu za chodu, ověřte, že j
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Přepsat uživatelsky určené pozadí plochy</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Použít tapetu poskytovanou motivem vzhledu</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(uživatelský motiv)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Otevřít složku motivu</translation>
     </message>
 </context>
 <context>
