@@ -11,7 +11,7 @@
     <message>
         <location filename="../colorLabel.cpp" line="61"/>
         <source>Select Color</source>
-        <translation>Farbe wählen</translation>
+        <translation>Wähle Farbe</translation>
     </message>
 </context>
 <context>
@@ -166,7 +166,7 @@
     <message>
         <location filename="../gtkconfig.ui" line="44"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK-Stil</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="63"/>
@@ -225,8 +225,18 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Benutzerdefiniertes Hintergrundbild überschreiben</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Hintergrundbild des Themas verwenden</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Benutzerthema)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Themenordner öffnen</translation>
     </message>
 </context>
 <context>
@@ -283,7 +293,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     <message>
         <location filename="../main.cpp" line="118"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK-Stil</translation>
     </message>
 </context>
 <context>
@@ -331,7 +341,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     <message>
         <location filename="../styleconfig.ui" line="162"/>
         <source>View Text:</source>
-        <translation>Textanzeige:</translation>
+        <translation>Anzeigetext:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="172"/>
