@@ -225,8 +225,18 @@ S&apos;assurer que &apos;xsettingsd&apos; est installé pour aider les applicati
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Remplacer le papier peint défini par l&apos;utilisateur</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Utiliser le fond d&apos;écran fourni par le thème</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Thème utilisateur)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Ouvrez le dossier du thème</translation>
     </message>
 </context>
 <context>
