@@ -225,8 +225,18 @@ Zorg dat &apos;xsettingsd&apos; geïnstalleerd is om GTK-programma&apos;s te hel
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Eigen ingestelde bureaubladachtergrond negeren</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Achtergrond uit thema gebruiken</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(eigen thema)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Themamap openen</translation>
     </message>
 </context>
 <context>
