@@ -225,8 +225,18 @@ Certifique-se de que o &apos;xsettingsd&apos; está instalado para ajudar as apl
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Substituir papel de parede do utilizador</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Usar papel de parede fornecido pelo tema</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Tema do Utilizador)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Abrir pasta de temas</translation>
     </message>
 </context>
 <context>
