@@ -279,7 +279,7 @@
     <message>
         <location filename="../touchpadconfig.ui" line="145"/>
         <source>DeviceInfoLabel</source>
-        <translation type="unfinished"></translation>
+        <translation>Geräteinformationen</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.cpp" line="85"/>
