@@ -33,7 +33,7 @@
     <name>LoadSettings</name>
     <message>
         <location filename="../loadsettings.cpp" line="98"/>
-        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
+        <source>Default monitor settings have been applied. Use lxqt-config-monitor for adjusting your monitor settings.</source>
         <translation>기본 모니터 설정이 적용되었습니다. 모니터 설정을 변경하려면 lxqt-config-monitor를 사용하십시오.</translation>
     </message>
 </context>
